@@ -115,9 +115,7 @@ fn identity_tests(tests: &mut Vec<TestDescAndFn>) -> Result<(), io::Error> {
     let dir = Path::new(env!("CARGO_MANIFEST_DIR"))
         .parent()
         .unwrap()
-        .parent()
-        .unwrap()
-        .join("parser")
+        .join("swc_ecma_parser")
         .join("tests")
         .join("test262-parser");
 
